Asciiquarium Redux (Web)

## Settings

### Basics

Speed
Density
Color
Treasure chest
Castle
Click action
Auto font (fit castle)
Font min size (px)
Font max size (px)
Other Options
FPS
Fish turning
AI behavior
Seed
Fish
Direction bias
Speed min
Speed max
Fish scale
Seaweed
Seaweed scale
Sway min
Sway max
Scene
Fish tank mode
Scene width (× screen)
Pan step (% of screen)
Fish tank margin (cols)
Waterline top (row)
Chest burst (s)
Spawn
Start delay min (s)
Start delay max (s)
Interval min (s)
Interval max (s)
Max concurrent specials
Global cooldown (s)
Special Weights
Set to 0 to disable
Shark
Fishhook
Whale
Ship
Ducks
Dolphins
Swan
Monster
Big Fish
Crab
Scuba Diver
Submarine
Fishhook
Hook dwell (s)

## About

Loading README…
Open README on GitHub